==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/app/models/cms_bind.rb <==
# -*- coding: utf-8 -*-
class CmsBind < ActiveRecord::Base
  belongs_to :cms_page, :foreign_key=> "cms_page_id"
  belongs_to :cms_template, :foreign_key=> "cms_template_id"
  has_many :items, :class_name => 'CmsBindItem', :foreign_key => 'cms_bind_id'

  # Rails2.3.2のnested_form に移行しやすくなるように名前をつけています。
  attr_accessor :items_attributes

  # CmsPublish::FileActionでどのように動作するべきかを判断するための属性です。
  # CmsPublishedProject#calc_type_keyの取り得る値が入ります。
  attr_accessor :publish_calc_type_key


  selectable_attr :position do
    entry '0', :top, '上'
    entry '1', :bottom, '下'
    entry '2', :left, '左'
    entry '3', :right, '右'
    entry '4', :center, '中央'
  end

  def set_bind_name
    template = CmsTemplate.find(cms_template_id, :include => :contents)
    #itemsの繰り返し
    items.each do |item|
      #テンプレート内容の繰り返し
      template.contents.each do |content|
        ec_tags = content.descriptions.scan(/<ec:bind(.{2}).+?"(.+?)"\/>/m)
        ec_tags.each do |ec_tag|
          if ec_tag[0] == item.no
            item.name = ec_tag[1]
          end
          break  if item.name
        end
        break if item.name
      end
    end
  end

  # ビューのファイル名の管理はCmsBindを中心に行います。
  # すべての公開するビューを取得するためには、全てのCmsBindに対して全てのロケールを指定することで取得できます。
  def published_filename(locale = :ja)
    if position_key == :center
      cms_page.published_filename(locale)
    else
      if items.empty?
        cms_template.published_filename(locale)
      else
        locale_str = (locale.to_s == 'ja') ? nil : '_' << locale.to_s.gsub(/\-/, '_')
        "#{cms_page.controller}/_#{cms_page.action}_#{position_key}#{locale_str}.html.erb"
      end
    end
  end

  def delete_at_publish?
    if position_key == :center
      cms_page.delete_at_publish
    else
      if items.empty?
        cms_template.delete_at_publish
      else
        cms_page.delete_at_publish
      end
    end
  end
  
  def generate_erb(contents)
    begin
      CmsXml.generate_erb(contents)
    rescue REXML::ParseException
      errors.add_to_base("XMLの記述が不正です")
    end
  end
  
  #
  # ビューを生成します。
  #
  def overwrite(file_action)
    return unless cms_template_id
    return unless cms_template
    case file_action.cms_publish.target_key
      when :production
        root_dir = EcRider.config.ec_front_root
      when :test
        root_dir = EcRider.config.ec_test_root
      else
        root_dir = EcRider.config.ec_admin_root
      end
    
    # バインドのNOと内容を取り出す
    bind_elements = {}
    self.items.each do |bind_item|
      if bind_item.code == 'content'
        bind_elements[bind_item.no] = {}
        bind_item.contents.each do |bind_content|
          bind_elements[bind_item.no][bind_content.locale] = bind_content.descriptions
        end if bind_item
      else
        bind_elements[bind_item.no] = bind_item.code
      end
    end
    
    if template_content = cms_template.send("content_#{file_action.locale.to_s}")
      descriptions = (template_content.descriptions || cms_template.content_ja.descriptions).dup
      # テンプレート中のbindタグを変換
      bind_elements.each_pair do |no, element|
        replacement = (element.class == String) ? "<ec:#{element}/>" : element[template_content.locale]
        descriptions.gsub!(/<ec:bind#{no}.+?\/>/m, replacement)
      end

      # .html.erbファイル生成
      path = File.join(root_dir, 'app', 'views', file_action.filepath)
      logger.info("deploying #{path}")
      dir = File.dirname(path)
      FileUtils.mkdir_p(dir) unless File.exist?(dir)
      open(path, 'w') do |f|
        # centerの場合は、先頭にレイアウトの記述を付加します。
        if position_key == :center && self.cms_page.action !~ /^_/
          partial_paths = self.cms_page.partial_paths(file_action.locale.to_s)
          [:top, :bottom, :left, :right].each do |position|
            partial_path = partial_paths[position] || file_action.cms_publish.default_template_paths[position]
            next if partial_path.blank?
            f.write(%{<% content_for(:layout_#{position}) do -%><%= render(:partial => "#{partial_path}") %><% end -%>})
          end
        end
        f.write generate_erb(descriptions)
      end
    end
  end
  
  #
  # ビューを削除します。
  #
  def delete(file_action)
    root_dir = file_action.cms_publish.target_key == :production ? EcRider.config.ec_front_root : EcRider.config.ec_test_root
    FileUtils.rm_f(File.join(root_dir, 'app/views', file_action.filepath))
  end
    
  class << self
    # 引数には、CmsPage.primary_page_idsと同様のCmsProject.status_keysの要素の配列を渡すことができます。
    def filename_map(options={})
      options = {
        :project_status_keys => [:opened],
        :project_ids => [],
        :find_options => {}
       }.update(options)
      find_options = {
        :include => [:cms_template, :cms_page, :items],
        :joins => "inner join cms_pages cond_cms_pages on cond_cms_pages.id = cms_binds.cms_page_id ",
        :conditions => ["(cond_cms_pages.id in (?))", 
          CmsPage.primary_page_ids({:project_status_keys => options[:project_status_keys], :project_ids => options[:project_ids]})]
      }.update(options[:find_options])
      cms_binds = CmsBind.find(:all, find_options)
      result = {}
      cms_binds.each do |cms_bind|
        next unless cms_bind.cms_template
        I18n.supported_locales.each do |locale|
          result[cms_bind.published_filename(locale.to_s)] = [cms_bind, locale.to_s]
        end
      end
      result
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/app/models/cms_bind.rb <==
# -*- coding: utf-8 -*-
class CmsBind < ActiveRecord::Base
  belongs_to :cms_page, :foreign_key=> "cms_page_id"
  belongs_to :cms_template, :foreign_key=> "cms_template_id"
  has_many :items, :class_name => 'CmsBindItem', :foreign_key => 'cms_bind_id'

  # Rails2.3.2のnested_form に移行しやすくなるように名前をつけています。
  attr_accessor :items_attributes

  # CmsPublish::FileActionでどのように動作するべきかを判断するための属性です。
  # CmsPublishedProject#calc_type_keyの取り得る値が入ります。
  attr_accessor :publish_calc_type_key


  selectable_attr :position do
    entry '0', :top, '上'
    entry '1', :bottom, '下'
    entry '2', :left, '左'
    entry '3', :right, '右'
    entry '4', :center, '中央'
  end

  selectable_attr :position_mobile do
    entry '0', :top, '上'
    entry '1', :bottom, '下'
    entry '4', :center, '中央'
  end

  def set_bind_name
    template = CmsTemplate.find(cms_template_id, :include => :contents)
    #itemsの繰り返し
    items.each do |item|
      #テンプレート内容の繰り返し
      template.contents.each do |content|
        ec_tags = content.descriptions.scan(/<ec:bind(.{2}).+?"(.+?)"\/>/m)
        ec_tags.each do |ec_tag|
          if ec_tag[0] == item.no
            item.name = ec_tag[1]
          end
          break  if item.name
        end
        break if item.name
      end
    end
  end

  # ビューのファイル名の管理はCmsBindを中心に行います。
  # すべての公開するビューを取得するためには、全てのCmsBindに対して全てのロケールを指定することで取得できます。
  def published_filename(locale = :ja)
    if position_key == :center
      cms_page.published_filename(locale)
    else
      if items.empty?
        cms_template.published_filename(locale)
      else
        if (CmsTemplateContent.carrier_ids.include?(locale.to_s))
          locale_str = (locale.to_s == 'docomo') ? '_mobile' : '_mobile_' << locale.to_s
        else
          locale_str = (locale.to_s == 'ja') ? nil : '_' << locale.to_s.gsub(/\-/, '_')
        end
        "#{cms_page.controller}/_#{cms_page.action}_#{position_key}#{locale_str}.html.erb"
      end
    end
  end

  def delete_at_publish?
    if position_key == :center
      cms_page.delete_at_publish
    else
      if items.empty?
        cms_template.delete_at_publish
      else
        cms_page.delete_at_publish
      end
    end
  end
  
  def generate_erb(contents)
    begin
      CmsXml.generate_erb(contents)
    rescue REXML::ParseException
      errors.add_to_base("XMLの記述が不正です")
    end
  end
  
  #
  # ビューを生成します。
  #
  def overwrite(file_action)
    return unless cms_template_id
    return unless cms_template
    case file_action.cms_publish.target_key
      when :production
        root_dir = EcRider.config.ec_front_root
      when :test
        root_dir = EcRider.config.ec_test_root
      else
        root_dir = EcRider.config.ec_admin_root
      end
    
    # バインドのNOと内容を取り出す
    bind_elements = {}
    self.items.each do |bind_item|
      if bind_item.code == 'content'
        bind_elements[bind_item.no] = {}
        bind_item.contents.each do |bind_content|
          bind_elements[bind_item.no][bind_content.locale] = bind_content.descriptions
        end if bind_item
      else
        bind_elements[bind_item.no] = bind_item.code
      end
    end
    
    if template_content = cms_template.send("content_#{file_action.locale.to_s}")
      descriptions = cms_template.get_descriptions(template_content).dup
      # テンプレート中のbindタグを変換
      bind_elements.each_pair do |no, element|
        replacement = (element.class == String) ? "<ec:#{element}/>" : element[template_content.locale]
        descriptions.gsub!(/<ec:bind#{no}.+?\/>/m, replacement)
      end

      # .html.erbファイル生成
      path = File.join(root_dir, 'app', 'views', file_action.filepath)
      logger.info("deploying #{path}")
      dir = File.dirname(path)
      FileUtils.mkdir_p(dir) unless File.exist?(dir)
      open(path, 'w') do |f|
        # centerの場合は、先頭にレイアウトの記述を付加します。
        if position_key == :center && self.cms_page.action !~ /^_/
          partial_paths = self.cms_page.partial_paths(file_action.locale.to_s)
          [:top, :bottom, :left, :right].each do |position|
            partial_path = partial_paths[position] || file_action.cms_publish.default_template_paths[cms_template.terminal_key][position]
            next if partial_path.blank?
            if partial_paths[position].nil? && CmsTemplateContent.carrier_ids.include?(file_action.locale.to_s)
              partial_path = file_action.locale.to_s == 'docomo' ? partial_path + '_mobile' : partial_path + '_mobile_' << file_action.locale.to_s
            end
            f.write(%{<% content_for(:layout_#{position}) do -%><%= render(:partial => "#{partial_path}") %><% end -%>})
          end
        end
        f.write generate_erb(descriptions)
      end
    end
  end
  
  #
  # ビューを削除します。
  #
  def delete(file_action)
    root_dir = file_action.cms_publish.target_key == :production ? EcRider.config.ec_front_root : EcRider.config.ec_test_root
    FileUtils.rm_f(File.join(root_dir, 'app/views', file_action.filepath))
  end
    
  class << self
    # 引数には、CmsPage.primary_page_idsと同様のCmsProject.status_keysの要素の配列を渡すことができます。
    def filename_map(options={})
      options = {
        :project_status_keys => [:opened],
        :project_ids => [],
        :find_options => {}
       }.update(options)
      find_options = {
        :include => [:cms_template, :cms_page, :items],
        :joins => "inner join cms_pages cond_cms_pages on cond_cms_pages.id = cms_binds.cms_page_id ",
        :conditions => ["(cond_cms_pages.id in (?))", 
          CmsPage.primary_page_ids({:project_status_keys => options[:project_status_keys], :project_ids => options[:project_ids]})]
      }.update(options[:find_options])
      cms_binds = CmsBind.find(:all, find_options)
      result = {}
      cms_binds.each do |cms_bind|
        next unless cms_bind.cms_template
        I18n.supported_locales.each do |locale|
          result[cms_bind.published_filename(locale.to_s)] = [cms_bind, locale.to_s]
        end
      end
      result
    end
  end
end
